Method: SlidayBackup::Compressor::Custom#command

Defined in:
lib/sliday_backup/compressor/custom.rb

#commandObject

Specify the system command to invoke a compressor, including any command-line arguments. e.g. @compressor.command = ‘pbzip2 -p2 -4’

The data to be compressed will be piped to the command’s STDIN, and it should write the compressed data to STDOUT. i.e. ‘cat file.tar | %command% > file.tar.%extension%`



15
16
17
# File 'lib/sliday_backup/compressor/custom.rb', line 15

def command
  @command
end